#include <stdio.h>
#include <ctype.h>

#include <algorithm>
#include <utility>
#include <vector>

using namespace std;

#define all(v) (v).begin(), (v).end()

struct point {
	int x, y;
	point(int x = 0, int y = 0): x(x), y(y) {}
	
	point operator +(point q) { return point(x + q.x, y + q.y); }
	point operator -(point q) { return point(x - q.x, y - q.y); }
	point operator -() { return point(-x, -y); }

	bool operator < (const point q) const {
		if (x != q.x) return x < q.x;
		else          return y < q.y;
	}
	bool operator ==(point q) { return x == q.x && y == q.y; }
	bool operator !=(point q) { return x != q.x || y != q.y; }
};

const int TAM = 100; // tamanho do buffer do validador
const int MAX = 1000; // valor máximo de N
const int INF = 0x3f3f3f3f;

int N;
point p[MAX];
char buf[TAM], ch;
vector< pair<point, point> > lista;

int gcd(int x, int y) {
	if (y == 0) return x;
	else        return gcd(y, x % y);
}

int main() {
	if (fgets(buf, sizeof(buf), stdin) == NULL ||
		 isspace(buf[0]) ||
		 sscanf(buf, "%d%c", &N, &ch) != 2 ||
		 ch != '\n') {
		fprintf(stderr, "*** ERRO: sintaxe inválida na linha 1 ***\n");
		exit(1);
	}
	if (N < 4 || 1000 < N) {
		fprintf(stderr, "*** ERRO: N fora do intervalo válido ***\n");
		exit(1);
	}
	for (int i = 0; i < N; i++) {
		if (fgets(buf, sizeof(buf), stdin) == NULL ||
			 isspace(buf[0]) ||
			 sscanf(buf, "%d %d%c", &p[i].x, &p[i].y, &ch) != 3 ||
			 ch != '\n') {
			fprintf(stderr, "*** ERRO: sintaxe inválida na linha %d ***\n", i + 2);
			exit(1);
		}
		if (p[i].x < -1000 || 1000 < p[i].x) {
			fprintf(stderr,
					  "*** ERRO: X fora do intervalo válido (linha %d) ***\n",
					  i + 1);
			exit(1);
		}
		if (p[i].y < -1000 || 1000 < p[i].y) {
			fprintf(stderr,
					  "*** ERRO: Y fora do intervalo válido (linha %d) ***\n",
					  i + 1);
			exit(1);
		}
	}

	if (fgets(buf, sizeof(buf), stdin) != NULL) {
		fprintf(stderr, "*** ERRO: lixo no final do arquivo ***\n");
		exit(1);
	}
	
	lista.clear();
	for (int i = 0; i < N; i++)
	for (int j = 0; j < i; j++) {
		point sum = p[i] + p[j], diff = p[i] - p[j];
		if (diff.x == 0 && diff.y == 0) {
			fprintf(stderr,
					  "*** ERRO: pontos coincidentes na entrada "
					  "(linhas %d, %d) ***\n",
					  i + 2, j + 2);
			exit(1);
		}
		if (diff.x < 0) diff = -diff;
		else if (diff.x == 0 && diff.y < 0) diff = -diff;
		int d = gcd(abs(diff.x), abs(diff.y));
		diff.x /= d; diff.y /= d;
		lista.push_back(make_pair(sum, diff));
	}
	// sentinela
	lista.push_back(make_pair(point( INF,  INF), point( INF,  INF)));

	sort(all(lista));

	int eq_sum = 1, eq_diff = 1, comb_sum = 0, comb_diff = 0;
	int tot = 0;
	for (int i = 1; i < (int) lista.size(); i++) {
		if (lista[i].first != lista[i-1].first) {
			tot += comb_sum;
			eq_sum = 1; comb_sum = 0;
			
			tot -= comb_diff;
			eq_diff = 1; comb_diff = 0;
		} else if (lista[i].second != lista[i-1].second) {
			comb_sum += eq_sum++;
			
			tot -= comb_diff;
			eq_diff = 1; comb_diff = 0;
		} else {
			comb_sum += eq_sum++;
			
			comb_diff += eq_diff++;
		}
	}
	printf("%d\n", tot);

	return 0;
}
